
.files-container {
    display: flex;
    gap: 10px;
}

.field-images select[name=images] {
    display: none; !important;
}

.files {
    flex: 1;
    width: 100%;
    margin-left: 20px;
}

.files .preloader,
.files .file-preview {
    position: relative;
    border: 1px solid #adadad;
    background: #fff;
    width: 100px;
    height: 100px;
    display: block;
    float: left;
    margin-right: 20px;
    margin-bottom: 20px;
}

.files .file-preview img {
    max-width: 98px;
    max-height: 98px;
}

.files .preloader {
    padding: 18px;
}

.files .remove-btn {
    position: absolute;
    right: -10px;
    top: -10px;
    box-sizing: border-box;
    display: block;
    transform: scale(var(--ggs,1));
    width: 20px;
    height: 20px;
    border: 2px solid #dd1144;
    border-radius: 20px
}

.files .remove-btn::before {
    content: "";
    display: block;
    box-sizing: border-box;
    position: absolute;
    width: 10px;
    height: 2px;
    background: #dd1144;
    border-radius: 5px;
    top: 7px;
    left: 3px
}

.dropzone.drop-section,
.drop-section {
    width: 150px;
    height: 100px;
    min-height: 100px;
    padding: 0;
    border: 1px solid rgba(0, 0, 0, 0.3);
    text-align: center;
    background: #fff;
    border-radius: 5px;
}

.dropzone .dz-message {
    margin: 20px 0 !important;
}
